---
title: config
---

# `marvin.cli.config`

## Functions

### `get`
```python
def get(key: str)
```
Get the value of a specific setting.

### `view`
```python
def view()
```
Display the current Marvin settings.

---

**Parent Module:** [`cli`](marvin-cli)
